import request from "@/utils/request";


// 查机构
export function selectSpdList(data) {
    return request({
        url:"/web/mcsList/selectSpdList",
        method:"post",
        data
    })
}

// 查询配送目录接口汇总
export function selectSplerMcsList(data) {
    return request({
        url:"/web/mcsList/selectSplerMcsList",
        method:"post",
        data
    })
}
// 查询招采耗材接口(弹窗分页)
export function selectMcsList(data) {
    return request({
        url:"/web/mcsList/selectMcsList",
        method:"post",
        data
    })
}
// 新增耗材配送目录(弹窗确认)
export function saveSplerMcs(data) {
    return request({
        url:"/web/mcsList/saveSplerMcs",
        method:"post",
        data
    })
}
// 耗材目录详情
export function selectMcsListById(data) {
    return request({
        url:"/web/mcsList/selectMcsListById",
        method:"post",
        data
    })
}
// 耗材详情修改 
export function insertSplerMcsList(data) {
    return request({
        url:"/web/mcsList/insertSplerMcsList",
        method:"post",
        data
    })
}

// 查询目录记录接口(汇 selectSplerMcsListIntf
export function selectSplerMcsListIntf(data) {
    return request({
        url:"/web/mcsList/selectSplerMcsListIntf",
        method:"post",
        data
    })
}
// // 查询目录记录接口详情接口
export function selectMcsListIntfById(data) {
    return request({
        url:"/web/mcsList/selectMcsListIntfById",
        method:"post",
        data
    })
}
// 新增耗材资质接口
export function insertMcsQua(data) {
    return request({
        url:"/web/mcsList/insertMcsQua",
        method:"post",
        data
    })
}
// 新增生产企业资质接口
export function insertFacQua(data) {
    return request({
        url:"/web/mcsList/insertFacQua",
        method:"post",
        data
    })
}
//目录删除
export function deleteSplerMcs(data) {
    return request({
        url:"/web/mcsList/deleteSplerMcs",
        method:"post",
        data
    })
}






// 药品目录管理查询--供应商端
// export function getGrpListByPage(data) {
//     return request({
//         url:"/web/splerDrugList/getGrpListByPage",
//         method:"post",
//         data
//     })
// }
// 配送商申请调价变更
export function PricChg(data) {
    return request({
        url:"/web/drugList/PricChg",
        method:"post",
        data
    })
}
// 调价状态变更
// export function savePricChgStas(data) {
//     return request({
//         url:"/web/splerDrugList/savePricChgStas",
//         method:"post",
//         data
//     })
// }
// 医院列表查询(调价)
export function getALLOrgTree(data) {
    return request({
        url:"/web/org/getALLOrgTree",
        method:"post",
        data
    })
}

// 获取医院药品目录(调价)
export function QueryHospDrugListTJ(data) {
    return request({
        url:"/web/drugList/QueryHospDrugListTJ",
        method:"post",
        data
    })
}


// 获取医院列表(对码)
export function QueryHospList(data) {
    return request({
        url:"/web/drugList/QueryHospList",
        method:"post",
        data
    })
}
// 获取医院药品目录(对码)
export function QueryHospDrugList(data) {
    return request({
        url:"/web/drugList/QueryHospDrugList",
        method:"post",
        data
    })
}
// 获取供应商药品目录
export function QuerySplerDrugList(data) {
    return request({
        url:"/web/drugList/QuerySplerDrugList",
        method:"post",
        data
    })
}
// 对码
export function DrugMatch(data) {
    return request({
        url:"/web/drugList/DrugMatch",
        method:"post",
        data
    })
}
// 取消对码
export function CancMatch(data) {
    return request({
        url:"/web/drugList/CancMatch",
        method:"post",
        data
    })
}
//下载模版
export function exportMcsTemplate(data) {
    return request({
        url:"/web/mcsList/exportMcsTemplate",
        method:"post",
        data,
        responseType: "blob",
    })
}
//目录导入
export function importMcsExcel(data) {
    return request({
        url:"/web/mcsList/importMcsExcel",
        method:"post",
        data,
        headers: { 'Content-Type': 'application/octet-stream'}
    })
}